'use strict';

const path = require('path');
const loaderUtils = require('loader-utils');
const getStyleLoader = require('./getStyleLoader');


module.exports = function (resoures) {
  let { resourcePath } = this;

  // 兼容windows的斜杠
  if (resourcePath) {
    resourcePath = resourcePath.split(path.sep).join('/');
  }
  
  function loaderPath($loader, $path) {
     const result = loaderUtils.stringifyRequest($loader, `${path.resolve(__dirname, $path)}`);
     return result.replace(/\"/g, '');
  }

  const scriptImport = (
    `var script = require('!${loaderPath(this, './script.js')}!babel-loader!${loaderPath(this, './selector.js')}?type=script!${resourcePath}')`
  );

  const templateImport = (
    `var template = require('!${loaderPath(this, './template.js')}!${loaderPath(this, './selector.js')}?type=template!${resourcePath}')`
  );

  var styleloaders = [loaderPath(this, './style.js'), 'css-loader'];
  const styleLoader = getStyleLoader(resoures);
  if (styleLoader) {
    styleloaders.push(styleLoader);
  }
  styleloaders.push(loaderPath(this, './selector.js'));
  
  const stylesLoaderPath = styleloaders.join('!');

  const styleImport = (
    `var style = require('!${stylesLoaderPath}?type=style!${resourcePath}')`
  );

  const componentImport = (
    `var components = require('!${loaderPath(this, './component.js')}!${resourcePath}')`
  );

  return `
    ${scriptImport}
    ${templateImport}
    ${styleImport}
    ${componentImport}

    module.exports = {
      template: template(),
      styles: '<style>' + style.default[0][1] + '</style>',
      ready: script.default,
      components: components(),
    };
  `;
};
